Usage
=====

Installation
------------

TODO: Add installation instructions here.


``pytest-codeblock`` Testing
----------------------------

.. code-block:: python

   x = 2
   assert x == 2


>>> print(7)
7

.. doctest::

   >>> 10
   10
